<?php

namespace EasyContent\WordPress\Api;

use EasyContent\WordPress\Exceptions\EasyContentResponseException;
use EasyContent\WordPress\Plugin;
use GuzzleHttp\Client as HttpClient;
use GuzzleHttp\Exception\BadResponseException;

final class Client extends HttpClient
{
    private static $_cachedClients = [];


    public static function create($publicKey = '')
    {
        $plugin = Plugin::getInstance();

        $publicKey = $publicKey ?: $plugin->getSettings()->publicKey;

        if ( isset( self::$_cachedClients[$publicKey] ) ) {
            return self::$_cachedClients[$publicKey];
        }

        $headers = [
            'Authorization' => "Bearer {$publicKey}"
        ];

        if ( $plugin->getRefererString() ) {
            $headers['Referer'] = $plugin->getRefererString();
        }

        $client = self::$_cachedClients[$publicKey] = new self( [
            'base_uri' => EASYCONTENT_ENDPOINT . '/plugin/api/',
            'allow_redirects' => false,
            'headers' => $headers
        ] );

        $plugin->log( 'Guzzle client was created', [
            'publicKey'  => $publicKey
        ] );

        return $client;
    }


    public function request($method, $uri = '', array $options = [])
    {
        $response = null;

        try {
            $response = parent::request( $method, $uri, $options );
        } catch ( BadResponseException $e ) {
            if ( $e->getResponse() && $e->getResponse()->getStatusCode() == 401 ) {
                $ecException = new EasyContentResponseException( $e );

                if ( $ecException->getCode() == EasyContentResponseException::UNAUTHORIZED_CODE ) {
                    Plugin::getInstance()->getSettings()->isPluginConnected = false;

                    delete_option( 'ec-public-api-key' );
                }
            }

            throw $e;
        }

        return $response;
    }
}
