<?php

namespace EasyContent\WordPress\Controllers;

use EasyContent\WordPress\Controllers\Actions\BaseAction;
use EasyContent\WordPress\Controllers\Actions\Main\Connection;
use EasyContent\WordPress\Controllers\Actions\Main\ImageProcessing;
use EasyContent\WordPress\Controllers\Actions\Main\Import;
use EasyContent\WordPress\Controllers\Actions\Main\PublishingOptions;
use EasyContent\WordPress\Controllers\Actions\Main\Seo;
use Symfony\Component\HttpFoundation\Request;

class Main
{
    /** @var Request $_request */
    protected $_request;

    /** @var string $_routes */
    protected $_routes = [];

    /** @var null|BaseAction $_action */
    protected $_action;


    public function __construct()
    {
        $this->_request = Request::createFromGlobals();

        $this->_routes = [
            'seo'                => Seo::class,
            'import'             => Import::class,
            'connection'         => Connection::class,
            'image-processing'   => ImageProcessing::class,
            'publishing-options' => PublishingOptions::class
        ];

        $this->_action = $this->createAction();
    }


    protected function createAction()
    {
        $page = $this->_request->query->get( 'page' );
        $page = $page ? (string)$page : '';

        if ( strpos( $page, 'easycontent-' ) !== 0 ) {
            return null;
        }

        $route = substr( $page, 12 );
        if ( ! $route ) {
            return null;
        }

        $actionClass = isset( $this->_routes[$route] ) ? $this->_routes[$route] : null;
        if ( ! $actionClass || ! class_exists( $actionClass ) ) {
            return null;
        }

        /** @var BaseAction $action */
        return new $actionClass;
    }


    public function renderAction()
    {
        echo $this->_action ? $this->_action->run( $this->_request ) : '';
    }
}
