<?php

namespace EasyContent\WordPress\Controllers\Actions\Main;

use EasyContent\WordPress\Controllers\Actions\BaseAction;
use EasyContent\WordPress\Db\Models\Category;
use EasyContent\WordPress\Forms\Entities\PublishingOptionsEntity;
use EasyContent\WordPress\Forms\Handlers\RefreshAllDataFormHandler;
use EasyContent\WordPress\Helpers\PublishingOptionsPageHelper;
use EasyContent\WordPress\Plugin;
use Symfony\Component\Form\Extension\Core\Type\CollectionType;
use Symfony\Component\Form\Extension\Core\Type\FormType;
use Symfony\Component\HttpFoundation\Request;

class PublishingOptions extends BaseAction
{
    const ACTION_SAVE_CHANGES = 'save-changes';


    public function run(Request $request)
    {
        $plugin = Plugin::getInstance();
        $action = isset( $_POST['action'] ) ? sanitize_text_field( $_POST['action'] ) : '';

        $form = $plugin->getFormFactory()
            ->createBuilder( FormType::class, new PublishingOptionsEntity(), [
                'validation_groups' => [PublishingOptionsEntity::class, 'determineValidationGroups']
            ] )
            ->add( 'postAuthorId' )
            ->add( 'postType' )
            ->add( 'postStatus' )
            ->add( 'commentsStatus' )
            ->add( 'categoryMappings', CollectionType::class, ['allow_add' => true] )
            ->add( 'defaultCategoryId' )
            ->getForm();

        if ( self::ACTION_SAVE_CHANGES === $action ) {
            $form->handleRequest( $request );

            if ( $form->isSubmitted() && $form->isValid() ) {
                $form->getData()->save();

                $plugin->noticesManager->addNotice( __( 'Publishing options were saved successfully', EASYCONTENT_TXTDOMAIN ) );
            } elseif ( count( $form->getErrors() ) > 0 ) {
                foreach ( $form->getErrors() as $error ) {
                    $plugin->noticesManager->addNotice( $error->getMessage(), 'error' );
                }
            }
        }


        ( new RefreshAllDataFormHandler() )->handle();


        $postCategories = get_categories( ['hide_empty' => false] );
        $categoriesList = PublishingOptionsPageHelper::createCategoriesDataStructure( $postCategories );

        return $this->render( 'admin/pages/publishing-options', [
            'formView' => $form->createView(),
            'accountName' => $plugin->getMisc()->accountName,
            'projectName' => $plugin->getMisc()->projectName,
            'users' => get_users(),
            'categoriesList' => $categoriesList,
            'easyContentCategoriesList' => PublishingOptionsPageHelper::createCategoriesDataStructure(
                Category::all(), null, 'id', 'parent_category_id'
            )
        ] );
    }
}
