<?php

namespace EasyContent\WordPress\Controllers\Actions\Main;

use EasyContent\WordPress\Controllers\Actions\BaseAction;
use EasyContent\WordPress\Forms\Entities\SeoPlugin;
use EasyContent\WordPress\Plugin;
use Symfony\Component\Form\Extension\Core\Type\ChoiceType;
use Symfony\Component\Form\Extension\Core\Type\FormType;
use Symfony\Component\HttpFoundation\Request;

class Seo extends BaseAction
{
    public function run(Request $request)
    {
        $plugin  = Plugin::getInstance();
        $plugins = [];

        if ( is_plugin_active( 'all-in-one-seo-pack/all_in_one_seo_pack.php' ) ) {
            $plugins['All in One SEO Pack'] = 'all-in-one-seo-pack';
        }

        if ( is_plugin_active( 'wordpress-seo/wp-seo.php' ) ) {
            $plugins['Yoast SEO'] = 'yoast-seo';
        }

        $form = null;

        if ( $plugins ) {
            $form = $plugin
                ->getFormFactory()
                ->createBuilder( FormType::class, new SeoPlugin() )
                ->add( 'slug', ChoiceType::class, ['choices' => $plugins] )
                ->getForm();

            $form->handleRequest( $request );

            if ( $form->isSubmitted() && $form->isValid() ) {
                $slug = $form->getData()->getSlug();
                $plugin->getSettings()->seoPlugin = $slug;

                $pluginName = array_search( $slug, $plugins );
                $successMessageTemplate = $pluginName
                    ? __( 'Success! %s plugin will be used.', EASYCONTENT_TXTDOMAIN )
                    : __( 'Success! No SEO plugin will be used.', EASYCONTENT_TXTDOMAIN );
                $successMessage = sprintf( $successMessageTemplate, $pluginName );

                $plugin->noticesManager->addNotice( $successMessage );
            } elseif ( count( $form->getErrors() ) > 0 ) {
                foreach ( $form->getErrors() as $error ) {
                    $plugin->noticesManager->addNotice( $error->getMessage(), 'error' );
                }
            }
        }

        return $this->render( 'admin/pages/seo', [
            'url'       => home_url(),
            'plugins'   => $plugins,
            'formView'  => $form ? $form->createView() : null
        ] );
    }
}
