<?php

namespace EasyContent\WordPress\Db\Models;

use EasyContent\WordPress\Db\BaseModel;
use EasyContent\WordPress\Forms\Entities\ArticlesFilter;
use EasyContent\WordPress\Plugin;
use EasyContent\WordPress\Post;
use Symfony\Component\Form\Form;

/**
 * @property integer $id Identical to remote article's ID
 * @property integer $current_workflow_stage_id
 * @property string $topic_name
 * @property string $title
 * @property integer $updated Timestamp that represents when remote article was updated last time
 */
class Article extends BaseModel
{
    public static function getListTableData(Form $form, $page = 1, $perPage = 20)
    {
        $wpdb = static::getWpdb();

        $tableName   = static::tableName();
        $wsTableName = WorkflowStage::tableName();
        $apTableName = ArticlePost::tableName();

        $orderColumn = isset( $_GET['orderby'] )
            ? sanitize_text_field( $_GET['orderby'] )
            : 'id';

        $order = isset( $_GET['order'] ) && 'asc' === $_GET['order'] ? 'ASC' : 'DESC';

        $offset = ( $page - 1 ) * $perPage;

        $mapping = [
            'id' => "`{$tableName}`.`id`",
            'topic_name' => '`topic_name`',
            'title' => '`title`',
            'updated' => '`updated`',
            'status' => "`name`",
            'last_synced' => '`sync_time`'
        ];

        $orderColumn = isset( $mapping[$orderColumn] ) ? $mapping[$orderColumn] : '`id`';

        /** @var ArticlesFilter $entity */
        $entity = $form->getData();
        $whereString = 'WHERE 1=1';

        if ( $searchString = $entity->getName() ) {
            $whereString .= " AND (`topic_name` LIKE '%{$searchString}%' OR `title` LIKE '%{$searchString}%')";
        }

        if ( $workflowStageId = $entity->getStatus() ) {
            $whereString .= " AND `current_workflow_stage_id` = {$workflowStageId}";
        }

        if ( $entity->getSynced() && $entity->getSynced() === 'synced' ) {
            $whereString .= " AND `sync_time` IS NOT NULL";
        } elseif ( $entity->getSynced() && $entity->getSynced() === 'not_synced' ) {
            $whereString .= " AND `sync_time` IS NULL";
        }


        $columns = implode( ', ', array_values( $mapping ) );

        $query = "SELECT {$columns}, `color`, `post_id`
            FROM `{$tableName}`
            LEFT JOIN `{$wsTableName}` ON `current_workflow_stage_id` = `{$wsTableName}`.`id`
            LEFT JOIN `{$apTableName}` ON `{$tableName}`.`id` = `article_id`
            {$whereString}
            ORDER BY {$orderColumn} {$order}
            LIMIT {$perPage} OFFSET {$offset};";

        $result = $wpdb->get_results( $query, ARRAY_A );

        return null === $result ? [] : $result;
    }


    public static function countListTableData(Form $form = null)
    {
        if ( ! $form ) {
            return static::countAll();
        }

        $wpdb = static::getWpdb();

        $tableName   = static::tableName();
        $wsTableName = WorkflowStage::tableName();
        $apTableName = ArticlePost::tableName();

        /** @var ArticlesFilter $entity */
        $entity = $form->getData();
        $whereString = 'WHERE 1=1';

        if ( $searchString = $entity->getName() ) {
            $whereString .= " AND (`topic_name` LIKE '%{$searchString}%' OR `title` LIKE '%{$searchString}%')";
        }

        if ( $workflowStageId = $entity->getStatus() ) {
            $whereString .= " AND `current_workflow_stage_id` = {$workflowStageId}";
        }

        if ( $entity->getSynced() && $entity->getSynced() === 'synced' ) {
            $whereString .= " AND `sync_time` IS NOT NULL";
        } elseif ( $entity->getSynced() && $entity->getSynced() === 'not_synced' ) {
            $whereString .= " AND `sync_time` IS NULL";
        }

        $query = "SELECT COUNT(`{$tableName}`.`id`)
            FROM `{$tableName}`
            LEFT JOIN `{$wsTableName}` ON `current_workflow_stage_id` = `{$wsTableName}`.`id`
            LEFT JOIN `{$apTableName}` ON `{$tableName}`.`id` = `article_id`
            {$whereString};";

        return (int)$wpdb->get_var( $query );
    }


    public static function getByPostId($postId)
    {
        $postId = (int)$postId;

        $wpdb = static::getWpdb();
        $tableName = static::tableName();
        $junctionTableName = ArticlePost::tableName();

        $query = "SELECT `{$tableName}`.`id`, `current_workflow_stage_id`, `topic_name`, `title`, `updated`
            FROM `{$tableName}`
            RIGHT JOIN `{$junctionTableName}` ON `{$junctionTableName}`.`article_id` = `{$tableName}`.`id`
            WHERE `post_id` = {$postId}
            AND `{$tableName}`.`id` IS NOT NULL
            LIMIT 1;";

        $row = $wpdb->get_row( $query, ARRAY_A );

        return $row ? static::create( $row ) : null;
    }


    public static function getFieldNames()
    {
        return ['id', 'current_workflow_stage_id', 'topic_name', 'title', 'updated'];
    }


    public function getEditRemoteArticleUrl()
    {
        $plugin = Plugin::getInstance();
        $base = $plugin->getMisc()->editUrlBase;

        return ! $base ? '#' : "{$base}{$this->id}";
    }


    public function getRelatedPostId()
    {
        $junction = ArticlePost::findByKey( $this->id, 'article_id' );

        return $junction ? (int)$junction->post_id : null;
    }


    public function getRelatedPost()
    {
        try {
            return new Post( $this->getRelatedPostId() );
        } catch ( \Exception $e ) {
            return null;
        }
    }


    /**
     * @return null|WorkflowStage
     */
    public function getCurrentWorkflowStage()
    {
        try {
            return WorkflowStage::findByKey( $this->current_workflow_stage_id );
        } catch ( \Exception $e ) {
            return null;
        }
    }


    public static function updateRelatedData($articles)
    {
        $seoPlugin = Plugin::getInstance()->getSettings()->getSeoPlugin();

        foreach ( $articles as $article ) {
            $articleDbObject = self::findByKey( $article['id'] );
            $post = $articleDbObject ? $articleDbObject->getRelatedPost() : null;

            if ( ! $post ) {
                continue;
            }

            $post->setContent( $article['content'] );

            if ( ! $seoPlugin ) {
                continue;
            }

            $post->updateMeta( [
                'meta_title' => $article['meta_title'],
                'meta_description' => $article['meta_description']
            ] );
        }
    }
}
