<?php

namespace EasyContent\WordPress\Db\Phinx\Console\Command;

use Phinx\Config\Config;
use Symfony\Component\Console\Input\InputInterface;
use Symfony\Component\Console\Output\OutputInterface;

class Migrate extends \Phinx\Console\Command\Migrate
{
    protected function loadConfig(InputInterface $input, OutputInterface $output)
    {
        global $wpdb;

        if ( ! $wpdb ) {
            throw new \Exception( __( '$wpdb was not defined', EASYCONTENT_TXTDOMAIN ) );
        }

        if ( ! defined( 'DB_NAME' ) ) {
            throw new \Exception( __( 'Name of database must be defined as DB_NAME constant', EASYCONTENT_TXTDOMAIN ) );
        }

        $DS = DIRECTORY_SEPARATOR;
        $migrationsPath = EASYCONTENT_DIR . $DS . implode( $DS, ['app', 'db', 'migrations'] );
        $migrationTableName = "{$wpdb->prefix}easycontent_migration";

        $this->setConfig( new Config( [
            'paths'        => [
                'migrations' => $migrationsPath
            ],
            'environments' => [
                'default_migration_table' => $migrationTableName,
                'default_database'        => 'production',
                'production'              => [
                    'adapter' => 'mysql',
                    'host'    => defined( 'DB_HOST' ) ? DB_HOST : 'localhost',
                    'name'    => DB_NAME,
                    'user'    => defined( 'DB_USER' ) ? DB_USER : 'root',
                    'pass'    => defined( 'DB_PASSWORD' ) ? DB_PASSWORD : '',
                    'port'    => defined( 'DB_PORT' ) ? DB_PORT : 3306,
                    'charset' => defined( 'DB_CHARSET' ) ? DB_CHARSET : 'utf8'
                ]
            ]
        ] ) );
    }
}
