<?php

namespace EasyContent\WordPress\Exceptions;

use GuzzleHttp\Exception\BadResponseException;

class EasyContentResponseException extends \Exception
{
    const UNAUTHORIZED_CODE = 100;
    const FORBIDDEN_CODE = 101;

    const ARTICLE_NOT_FOUND_CODE = 200;
    const ARTICLE_BAD_REQUEST_CODE = 201;
    const ARTICLE_SERVER_ERROR_CODE = 202;

    const WORKFLOW_STAGE_NOT_FOUND_CODE = 300;
    const WORKFLOW_STAGE_BAD_REQUEST_CODE = 301;

    const REVISION_SERVER_ERROR_CODE = 402;

    const CONNECTION_REQUIRED_HEADERS_MISSING_CODE = 500;
    const CONNECTION_KEYS_NOT_VALID_CODE = 501;


    protected $name;
    protected $status;
    protected $type;

    public function __construct(BadResponseException $e)
    {
        if ( ! $e->getResponse() ) {
            return;
        }

        $json  = (string)$e->getResponse()->getBody();
        $error = json_decode( $json );

        if ( null === $error || ! is_object( $error ) ) {
            return;
        }

        $this->name   = $error->name;
        $this->status = $error->status;
        $this->type   = isset( $error->type  ) ? $error->type : null;

        parent::__construct( $error->message, $error->code, $e );
    }


    public function getName()
    {
        return $this->name;
    }


    public function getStatus()
    {
        return $this->status;
    }


    public function getType()
    {
        return $this->type;
    }
}
