<?php

namespace EasyContent\WordPress\Forms\Entities;

use EasyContent\WordPress\Forms\Constraints as AssertApp;
use EasyContent\WordPress\Plugin;
use Symfony\Component\Form\FormInterface;
use Symfony\Component\Validator\Constraints as Assert;

class PublishingOptionsEntity
{
    /**
     * @Assert\NotNull
     * @Assert\GreaterThan(-1)
     * @AssertApp\WordPressUserExists
     */
    protected $postAuthorId;

    /**
     * @Assert\NotNull
     * @Assert\Type(type = "string")
     * @Assert\Choice({"post", "page"})
     */
    protected $postType;

    /**
     * @Assert\NotNull
     * @Assert\Type(type = "string")
     * @Assert\Choice({"publish", "draft", "pending", "private"})
     */
    protected $postStatus;

    /**
     * @Assert\NotNull
     * @Assert\Type(type = "string")
     * @Assert\Choice({"open", "closed"})
     */
    protected $commentsStatus;

    /**
     *
     */
    protected $categoryMappings;

    /**
     * @Assert\NotNull(groups={"postSelected"})
     * @Assert\GreaterThan(
     *     value = 0,
     *     groups={"postSelected"}
     * )
     * @AssertApp\PostCategoryExists(groups={"postSelected"})
     */
    protected $defaultCategoryId;


    public function __construct()
    {
        $settings = Plugin::getInstance()->getSettings();

        $this->setPostAuthorId( $settings->getPostAuthorId() );
        $this->setPostType( $settings->postType );
        $this->setPostStatus( $settings->postStatus );
        $this->setCommentsStatus( $settings->commentsStatus );
        $this->setCategoryMappings( $settings->mappings );
        $this->setDefaultCategoryId( $settings->defaultCategoryId );
    }


    public function getPostAuthorId()
    {
        return $this->postAuthorId;
    }

    public function setPostAuthorId($id)
    {
        $this->postAuthorId = $id;
    }


    public function getPostType()
    {
        return $this->postType;
    }

    public function setPostType($type)
    {
        $this->postType = $type;
    }


    public function getPostStatus()
    {
        return $this->postStatus;
    }

    public function setPostStatus($status)
    {
        $this->postStatus = $status;
    }


    public function getCommentsStatus()
    {
        return $this->commentsStatus;
    }

    public function setCommentsStatus($status)
    {
        $this->commentsStatus = $status;
    }


    public function getCategoryMappings()
    {
        return $this->categoryMappings;
    }

    public function setCategoryMappings(array $mappings)
    {
        $this->categoryMappings = $mappings;
    }


    public function getDefaultCategoryId()
    {
        return $this->defaultCategoryId;
    }

    public function setDefaultCategoryId($id)
    {
        $this->defaultCategoryId = $id;
    }


    public function save()
    {
        $settings = Plugin::getInstance()->getSettings();

        $settings->postAuthorId   = $this->getPostAuthorId();
        $settings->postType       = $this->getPostType();
        $settings->postStatus     = $this->getPostStatus();
        $settings->commentsStatus = $this->getCommentsStatus();

        if ( $this->getPostType() === 'page' ) {
            return;
        }

        $settings->mappings = $this->getCategoryMappings();
        $settings->defaultCategoryId = $this->getDefaultCategoryId();
    }


    public static function determineValidationGroups(FormInterface $form)
    {
        return $form->getData()->getPostType() === 'post'
            ? ['Default', 'postSelected']
            : ['Default'];
    }
}
