<?php

namespace EasyContent\WordPress\Forms\Handlers;

use EasyContent\WordPress\Api\Models\Article as ArticleApiModel;
use EasyContent\WordPress\Api\Models\Category as CategoryApiModel;
use EasyContent\WordPress\Api\Models\WorkflowStage as StageApiModel;
use EasyContent\WordPress\Db\Models\Article as ArticleDbModel;
use EasyContent\WordPress\Db\Models\Category as CategoryDbModel;
use EasyContent\WordPress\Db\Models\WorkflowStage as StageDbModel;
use EasyContent\WordPress\Plugin;

class RefreshAllDataFormHandler
{
    public function handle()
    {
        if ( ! isset( $_POST['action'] ) ) {
            return;
        }

        $action = sanitize_text_field( $_POST['action'] );

        if ( 'refresh-all' !== $action ) {
            return;
        }

        $nm = Plugin::getInstance()->noticesManager;

        try {
            $freshCategories = CategoryApiModel::findAll( true );
            CategoryDbModel::setDatabaseCache( $freshCategories );

            $freshArticles = ArticleApiModel::findAll( true );
            $freshArticles = array_map( function(ArticleApiModel $article) {
                unset( $article->categories );
                return $article;
            }, $freshArticles );
            $articles = ArticleDbModel::setDatabaseCache( $freshArticles );
            ArticleDbModel::updateRelatedData( $articles );

            $freshStages = StageApiModel::findAll( true );
            StageDbModel::setDatabaseCache( $freshStages );
        } catch ( \Exception $e ) {
            $nm->addNotice( $e->getMessage(), 'error' );
            return;
        }

        $nm->addNotice( __( 'All data has been updated', EASYCONTENT_TXTDOMAIN ) );
    }
}
