<?php

namespace EasyContent\WordPress\Forms\Validators;

use EasyContent\WordPress\Db\Models\WorkflowStage;
use EasyContent\WordPress\Forms\Constraints\WorkflowStageExists;
use Symfony\Component\Form\Exception\UnexpectedTypeException;
use Symfony\Component\Validator\Constraint;
use Symfony\Component\Validator\ConstraintValidator;

class WorkflowStageExistsValidator extends ConstraintValidator
{
    public function validate($stageId, Constraint $constraint)
    {
        if ( ! $constraint instanceof WorkflowStageExists ) {
            throw new UnexpectedTypeException( $constraint, WorkflowStageExists::class );
        }

        // custom constraints should ignore null and empty values to allow
        // other constraints (NotBlank, NotNull, etc.) take care of that
        if ( null === $stageId || '' === $stageId ) {
            return;
        }

        if ( 0 === (int)$stageId ) {
            return;
        }

        $exists = true;

        try {
            $workflowStage = WorkflowStage::findByKey( $stageId );
            $exists = !!$workflowStage;
        } catch ( \Exception $e ) {
            $exists = false;
        }

        if ( ! $exists ) {
            $this->context
                ->buildViolation( $constraint->message )
                ->setParameter( '{id}', $stageId )
                ->addViolation();
        }
    }
}
