<?php

namespace EasyContent\WordPress\Helpers;

use EasyContent\WordPress\Api\Models\Article as ArticleAPIModel;
use EasyContent\WordPress\Db\Models\Article;
use EasyContent\WordPress\Db\Models\ArticlePost;
use EasyContent\WordPress\Exceptions\EasyContentResponseException;
use EasyContent\WordPress\Post;
use GuzzleHttp\Exception\BadResponseException;

final class ArticleWorkflowStageUpdater
{
    /**
     * @param Post $post
     * @param int $workflowStageId
     * @return null|\WP_Error
     */
    public function update(Post $post, $workflowStageId)
    {
        $relatedArticleId = $post->getArticle()->id;

        try {
            $remoteArticle = new ArticleAPIModel( $relatedArticleId );
            $remoteArticle->updateWorkflowStage( $workflowStageId );
        } catch ( BadResponseException $e ) {
            $ecException = new EasyContentResponseException( $e );

            if ( $ecException->getCode() == EasyContentResponseException::ARTICLE_NOT_FOUND_CODE ) {
                Article::deleteByPrimaryKey( $relatedArticleId );
                ArticlePost::detach( $relatedArticleId, $post->getId() );

                return new \WP_Error( 19, __( "Remote article doesn't exist", EASYCONTENT_TXTDOMAIN ) );
            }

            return new \WP_Error( $e->getCode(), $ecException->getMessage() );
        }

        Article::update(
            ['current_workflow_stage_id' => $workflowStageId],
            ['id' => $relatedArticleId],
            ['%d'],
            ['%d']
        );

        return null;
    }
}
