<?php

namespace EasyContent\WordPress\Rest;

use EasyContent\WordPress\Rest\Actions\BaseAction;

class RestManager
{
    const EASYCONTENT_V1_NAMESPACE = 'easycontent/v1';


    /** @var string $namespace */
    protected $namespace;

    /** @var array|string[] $actionsConfig */
    protected $actionsConfig = [];


    public function __construct($namespace, $config = [])
    {
        $this->namespace = $namespace;
        $this->actionsConfig = $config;

        add_action( 'rest_api_init', [$this, 'registerRoutes'] );
    }


    public function registerRoutes()
    {
        foreach ( $this->actionsConfig as $route => $className ) {
            /** @var BaseAction $action */
            $action = new $className;

            register_rest_route( $this->namespace, $route, [
                'methods'  => $action->getMethodsString(),
                'callback' => [$action, 'run'],
                'permission_callback' => [$action, 'checkAccess'],
                'args' => $action->getArgumentsConfig()
            ] );
        }
    }
}
