<?php

namespace EasyContent\WordPress\Rest\Actions;

use EasyContent\WordPress\Api\Models\Article as ArticleAPIModel;
use EasyContent\WordPress\Db\Models\WorkflowStage;

class PublishArticle extends BaseAction
{
    protected $methods = ['POST'];


    public function run(\WP_REST_Request $request)
    {
        // URL: POST http://easycontent.wp/wp-json/easycontent/v1/posts

        if ( $request->get_body() === '' ) {
            return new \WP_Error( 4, __( 'Empty request body is not allowed', EASYCONTENT_TXTDOMAIN ) );
        }

        $data = json_decode( $request->get_body(), true );

        if ( null === $data || ! isset( $data['article_id'] ) ) {
            return new \WP_Error( 5, __( 'Article ID is required', EASYCONTENT_TXTDOMAIN ) );
        }

        try {
            $remoteArticle = ArticleAPIModel::findOne( $data['article_id'] );

            if ( ! $remoteArticle ) {
                return new \WP_Error( 6, __( 'EasyContent.io article with this ID was not found', EASYCONTENT_TXTDOMAIN ) );
            }

            $hasKSES = false !== has_filter( 'content_save_pre', 'wp_filter_post_kses' );

            if ( $hasKSES ) {
                kses_remove_filters();
            }

            $stage = WorkflowStage::findByKey( $remoteArticle->current_workflow_stage_id );
            $post  = $remoteArticle->import( $stage );

            if ( $hasKSES ) {
                kses_init_filters();
            }

            return new \WP_REST_Response( $post->getFrontendData() ?: new \stdClass(), 201 );
        } catch ( \Exception $e ) {
            return new \WP_Error( $e->getCode(), $e->getMessage() );
        }
    }
}
