<?php

namespace EasyContent\WordPress\Rest\Actions;

use EasyContent\WordPress\Exceptions\EasyContentResponseException;
use EasyContent\WordPress\Plugin;
use EasyContent\WordPress\Post;
use GuzzleHttp\Exception\BadResponseException;

class PullArticle extends BaseAction
{
    protected $methods = ['POST'];


    public function getArgumentsConfig()
    {
        return [
            'article_id' => [
                'type'              => 'integer',
                'required'          => true,
                'sanitize_callback' => 'absint'
            ]
        ];
    }


    public function run(\WP_REST_Request $request)
    {
        try {
            $post = Post::createFromArticleId( $request['article_id'] );

            if ( ! $post ) {
                throw new \Exception( __( 'Invalid article ID', EASYCONTENT_TXTDOMAIN ), 9 );
            }

            return new \WP_REST_Response( $post->pull() ?: new \stdClass() );
        } catch ( BadResponseException $e ) {
            $ecException = new EasyContentResponseException( $e );

            if ( $ecException->getCode() == EasyContentResponseException::ARTICLE_NOT_FOUND_CODE ) {
                $message  = __( 'Remote article was not found in %s project. Do you want to unlink it from this post? ', EASYCONTENT_TXTDOMAIN );
                $message .= __( 'If you unlink it and then push this post to EasyContent, a new article will be created.', EASYCONTENT_TXTDOMAIN );
                $message  = sprintf( $message, Plugin::getInstance()->getMisc()->projectName );

                return new \WP_Error( $e->getCode(), $message );
            }

            return new \WP_Error( $e->getCode(), $ecException->getMessage() );
        } catch (\Exception $e) {
            return new \WP_Error( $e->getCode(), $e->getMessage() );
        }
    }
}
