<?php

namespace EasyContent\WordPress\Rest\Actions;

use EasyContent\WordPress\Plugin;
use EasyContent\WordPress\Post;
use GuzzleHttp\Exception\BadResponseException;
use EasyContent\WordPress\Exceptions\EasyContentResponseException;

class PushPost extends BaseAction
{
    protected $methods = ['POST'];


    public function getArgumentsConfig()
    {
        return [
            'post_id' => [
                'type'              => 'integer',
                'required'          => true,
                'sanitize_callback' => 'absint'
            ]
        ];
    }


    public function run(\WP_REST_Request $request)
    {
        try {
            if ( ! Plugin::getInstance()->getSettings()->isPluginConnected ) {
                $message = __( "EasyContent plugin isn't connected to your EasyContent account. Please connect it on the EasyContent connection page in your plugin menu", EASYCONTENT_TXTDOMAIN );
                throw new \Exception( $message, 11 );
            }

            $post = new Post( (int)$request['post_id'] );
            return new \WP_REST_Response( $post->push() ?: new \stdClass() );
        } catch ( BadResponseException $e ) {
            $ecException = new EasyContentResponseException( $e );

            if ( $ecException->getCode() == EasyContentResponseException::ARTICLE_NOT_FOUND_CODE ) {
                $message  = __( 'Remote article was not found in %s project. Do you want to unlink it from this post? ', EASYCONTENT_TXTDOMAIN );
                $message .= __( 'If you unlink it and then push this post to EasyContent, a new article will be created.', EASYCONTENT_TXTDOMAIN );
                $message  = sprintf( $message, Plugin::getInstance()->getMisc()->projectName );

                return new \WP_Error( $e->getCode(), $message );
            }

            return new \WP_Error( $e->getCode(), $ecException->getMessage() );
        } catch ( \Exception $e ) {
            return new \WP_Error( $e->getCode(), $e->getMessage() );
        }
    }
}
