<?php

namespace EasyContent\WordPress\Storages;

class BaseOptionsStorage
{
    protected $isLoaded = false;

    protected $values = [];


    public function __construct()
    {
        $this->values = $this->getDefaults();
    }


    public function __get($name)
    {
        if ( ! array_key_exists( $name, $this->values ) ) {
            $error = __( "Option %s doesn't exist", EASYCONTENT_TXTDOMAIN );
            throw new \InvalidArgumentException( sprintf( $error, $name ) );
        }

        if ( ! $this->isLoaded ) {
            $this->load();
        }

        return $this->values[$name];
    }


    public function __set($name, $value)
    {
        if ( $this->{$name} === $value ) {
            return;
        }

        $mappings = $this->getMappings();

        if ( ! isset( $mappings[$name]['name'] ) || ! is_string( $mappings[$name]['name'] ) ) {
            $message = __( 'Property does not exist or user passed invalid property name', EASYCONTENT_TXTDOMAIN );
            throw new \Exception( $message );
        }

        if ( ! isset( $mappings[$name]['filter'] ) || ! is_callable( $mappings[$name]['filter'] ) ) {
            throw new \Exception( __( 'Invalid callback function', EASYCONTENT_TXTDOMAIN ) );
        }

        $value = call_user_func( $mappings[$name]['filter'], $value );
        if ( update_option( $mappings[$name]['name'], $value, false ) ) {
            $this->values[$name] = $value;
        }
    }


    protected function getDefaults()
    {
        return [];
    }


    protected function getMappings()
    {
        return [];
    }


    protected function load()
    {
        if ( $this->isLoaded ) {
            return;
        }

        $mappings = $this->getMappings();

        if ( ! $mappings ) {
            $this->isLoaded = true;
            return;
        }

        $optionsNames = array_column( $mappings, 'name' );
        $reverseMappings = array_combine( $optionsNames, array_keys( $mappings ) );

        global $wpdb;

        $query = "SELECT * FROM `{$wpdb->options}` WHERE `option_name` IN ('" . implode( "', '", $optionsNames) . "');";
        $rows = $wpdb->get_results( $query, ARRAY_A ); // $rows variable can be NULL or array

        if ( null === $rows ) {
            $this->isLoaded = true;
            return;
        }

        foreach ( $rows as $row ) {
            $propertyName = $reverseMappings[$row['option_name']];
            $value = maybe_unserialize( $row['option_value'] );
            $value = call_user_func( $mappings[$propertyName]['filter'], $value );

            $this->values[$propertyName] = $value;
        }

        $this->isLoaded = true;
    }
}
