<?php
/**
 * @var EasyContent\WordPress\View $this
 * @var array|WP_User[] $users
 * @var array|WP_Term[] $categoriesList
 * @var string $accountName
 * @var string $projectName
 * @var array|stdClass[] $easyContentCategoriesList
 * @var Symfony\Component\Form\FormView $formView
 */

use EasyContent\WordPress\Helpers\PublishingOptionsPageHelper as PageHelper;

?>
<div class="wrap">
    <h1 class="wp-heading-inline">EasyContent</h1>

    <form action="<?= admin_url( 'admin.php?page=easycontent-publishing-options' ) ?>" method="post" class="ec-header-form">
        <button type="submit" name="action" value="refresh-all" class="button-primary button-large page-title-action">
            <?= esc_html__( 'Refresh all data', EASYCONTENT_TXTDOMAIN ) ?>
        </button>
    </form>

    <hr class="wp-header-end">

    <?php $this->renderGlobalNotices() ?>

    <h2><?= esc_html( get_admin_page_title() ) ?></h2>

    <p><?= sprintf( __( 'You are currently connected to project <strong>%s</strong> in account <strong>%s</strong>.', EASYCONTENT_TXTDOMAIN ), $projectName, $accountName) ?></p>

    <p><?= esc_html__( 'Please set up your publishing options', EASYCONTENT_TXTDOMAIN ) ?></p>

    <form method="post" novalidate="novalidate">
        <table class="form-table">
            <tbody>
                <tr>
                    <th scope="row">
                        <label for="ec-post-user"><?= esc_html__( 'Post author', EASYCONTENT_TXTDOMAIN ) ?></label>
                    </th>
                    <td>
                        <?php if ( $users ) : ?>
                            <select class="regular-text" name="<?= esc_attr( $formView['postAuthorId']->vars['full_name'] ) ?>" id="ec-post-user">
                                <option value="0" <?php selected( $formView['postAuthorId']->vars['value'], 0 ) ?>>&mdash;</option>

                                <?php foreach ( $users as $user ) : ?>
                                    <option value="<?= esc_attr( $user->ID ) ?>" <?php selected( $formView['postAuthorId']->vars['value'], $user->ID ) ?>>
                                        <?= esc_html( $user->display_name ) ?>
                                    </option>
                                <?php endforeach ?>
                            </select>
                        <?php else : ?>
                            <i><?= esc_html__( 'No users available', EASYCONTENT_TXTDOMAIN ) ?></i>
                        <?php endif ?>
                    </td>
                </tr>
                <tr>
                    <th scope="row">
                        <label for="ec-post-type"><?= esc_html__( 'Post type', EASYCONTENT_TXTDOMAIN ) ?></label>
                    </th>
                    <td>
                        <select class="regular-text" name="<?= esc_attr( $formView['postType']->vars['full_name'] ) ?>" id="ec-post-type">
                            <option value="post" <?php selected( $formView['postType']->vars['value'], 'post' ) ?>>
                                <?= esc_html__( 'post', EASYCONTENT_TXTDOMAIN ) ?>
                            </option>
                            <option value="page" <?php selected( $formView['postType']->vars['value'], 'page' ) ?>>
                                <?= esc_html__( 'page', EASYCONTENT_TXTDOMAIN ) ?>
                            </option>
                        </select>
                    </td>
                </tr>
                <tr>
                    <th scope="row">
                        <label for="ec-post-status"><?= esc_html__( 'Post status', EASYCONTENT_TXTDOMAIN ) ?></label>
                    </th>
                    <td>
                        <select class="regular-text" name="<?= esc_attr( $formView['postStatus']->vars['full_name'] ) ?>" id="ec-post-status">
                            <option value="publish" <?php selected( $formView['postStatus']->vars['value'], 'publish' ) ?>>
                                <?= esc_html__( 'publish', EASYCONTENT_TXTDOMAIN ) ?>
                            </option>
                            <option value="draft"   <?php selected( $formView['postStatus']->vars['value'], 'draft' ) ?>>
                                <?= esc_html__( 'draft', EASYCONTENT_TXTDOMAIN ) ?>
                            </option>
                            <option value="pending" <?php selected( $formView['postStatus']->vars['value'], 'pending' ) ?>>
                                <?= esc_html__( 'pending', EASYCONTENT_TXTDOMAIN ) ?>
                            </option>
                            <option value="private" <?php selected( $formView['postStatus']->vars['value'], 'private' ) ?>>
                                <?= esc_html__( 'private', EASYCONTENT_TXTDOMAIN ) ?>
                            </option>
                        </select>
                    </td>
                </tr>
                <tr>
                    <th scope="row">
                        <label for="ec-post-comments-status"><?= esc_html__( 'Comments status', EASYCONTENT_TXTDOMAIN ) ?></label>
                    </th>
                    <td>
                        <select class="regular-text" name="<?= esc_attr( $formView['commentsStatus']->vars['full_name'] ) ?>" id="ec-post-comments-status">
                            <option value="open" <?php selected( $formView['commentsStatus']->vars['value'], 'open' ) ?>>
                                <?= esc_html__( 'open', EASYCONTENT_TXTDOMAIN ) ?>
                            </option>
                            <option value="closed" <?php selected( $formView['commentsStatus']->vars['value'], 'closed' ) ?>>
                                <?= esc_html__( 'closed', EASYCONTENT_TXTDOMAIN ) ?>
                            </option>
                        </select>
                    </td>
                </tr>
            </tbody>
        </table>

        <div id="ec-post-category-settings-wrapper" <?= $formView['postType']->vars['value'] === 'page' ? 'style="display: none;"' : '' ?>>
            <h2><?= esc_html__( 'Map your WordPress categories to EasyContent categories (optional)', EASYCONTENT_TXTDOMAIN ) ?></h2>
            <p><?= esc_html__( 'After mapping all posts with the selected EasyContent category will be automatically assigned one or several of your WordPress categories during push or pull.', EASYCONTENT_TXTDOMAIN ) ?></p>

            <table>
                <thead>
                    <tr>
                        <th style="width: 215px; text-align: left;"><?= esc_html__( 'WordPress category', EASYCONTENT_TXTDOMAIN ) ?></th>
                        <th style="text-align: left;"><?= esc_html__( 'EasyContent category', EASYCONTENT_TXTDOMAIN ) ?></th>
                    </tr>
                </thead>
                <tbody>
                    <?= PageHelper::renderCategoriesTableBody( $categoriesList, $easyContentCategoriesList ) ?>
                </tbody>
            </table>

            <table class="form-table">
                <tbody>
                    <tr>
                        <th scope="row">
                            <label for="ec-default-cat-mapping"><?= esc_html__( 'Assign default WP category when there is no mapping', EASYCONTENT_TXTDOMAIN ) ?></label>
                        </th>
                        <td>
                            <?= PageHelper::renderCategoriesList(
                                $categoriesList,
                                $formView['defaultCategoryId']->vars['full_name'],
                                'ec-default-cat-mapping',
                                $formView['defaultCategoryId']->vars['value']
                            ) ?>
                        </td>
                    </tr>
                </tbody>
            </table>
        </div>

        <p class="submit">
            <button type="submit" name="action" value="save-changes" id="submit" class="button button-primary">
                <?= esc_html__( 'Save Changes', EASYCONTENT_TXTDOMAIN ) ?>
            </button>
        </p>

    </form>
</div>
