<?php
/**
 * @var EasyContent\WordPress\View $this
 * @var array|string[] $plugins
 * @var string $url
 * @var null|Symfony\Component\Form\FormView $formView
 */
?>
<div class="wrap">
    <h1><?= esc_html( get_admin_page_title() ) ?></h1>

    <?php $this->renderGlobalNotices() ?>

    <?php if ( ! $plugins ) : ?>
        <p><?= esc_html__( 'Our system works with All in One SEO Pack and Yoast SEO plugins.', EASYCONTENT_TXTDOMAIN ) ?></p>
        <p>
            <?= esc_html__( 'Install one of them for meta title and meta description to be imported from EasyContent to', EASYCONTENT_TXTDOMAIN ) ?>
            <a href="<?= esc_url( $url ) ?>"><?= esc_html( $url ) ?></a>
        </p>
    <?php elseif ( 1 === count( $plugins ) ) : ?>
        <p><?= esc_html( sprintf( __( 'We have detected that you have %s installed.', EASYCONTENT_TXTDOMAIN ), current( $plugins ) ) ) ?></p>
        <p>
            <?= esc_html__( 'Meta titles and meta descriptions will be imported from EasyContent to', EASYCONTENT_TXTDOMAIN ) ?>
            <a href="<?= esc_url( $url ) ?>"><?= esc_html( $url ) ?></a>
        </p>
        <p><?= esc_html__( "You don't need to do anything.", EASYCONTENT_TXTDOMAIN ) ?></p>
    <?php else : ?>
        <p><?= esc_html__( 'We have detected that you have both Yoast SEO and All in One SEO Pack installed.', EASYCONTENT_TXTDOMAIN ) ?></p>
        <p>
            <?= esc_html__( 'Please select which one we should use to import meta titles and meta descriptions from EasyContent to', EASYCONTENT_TXTDOMAIN ) ?>
            <a href="<?= esc_url( $url ) ?>"><?= esc_html( $url ) ?></a>
        </p>

        <form action="" method="<?= esc_attr( $formView->vars['method'] ) ?>">
            <select name="<?= esc_attr( $formView['slug']->vars['full_name'] ) ?>" id="<?= esc_attr( $formView['slug']->vars['id'] ) ?>">
                <option value="" <?php selected( $formView['slug']->vars['value'], '' ) ?>>&mdash;</option>

                <?php foreach ( $plugins as $name => $slug ) : ?>
                    <option value="<?= esc_attr( $slug ) ?>" <?php selected( $formView['slug']->vars['value'], $slug ) ?>>
                        <?= esc_html( $name ) ?>
                    </option>
                <?php endforeach ?>
            </select>

            <input type="submit" name="submit" class="button button-primary" value="<?= esc_attr__( 'Save Changes', EASYCONTENT_TXTDOMAIN ) ?>">
        </form>
    <?php endif ?>
</div>
